@@ -43,7 +43,7 @@ our $DETACH    = "catalyst_detach\n";
 require Module::Pluggable::Fast;
 
 # Helper script generation
-our $CATALYST_SCRIPT_GEN = 10;
+our $CATALYST_SCRIPT_GEN = 11;
 
 __PACKAGE__->mk_classdata($_)
   for qw/components arguments dispatcher engine log dispatcher_class
@@ -54,7 +54,7 @@ __PACKAGE__->engine_class('Catalyst::Engine::CGI');
 __PACKAGE__->request_class('Catalyst::Request');
 __PACKAGE__->response_class('Catalyst::Response');
 
-our $VERSION = '5.49_04';
+our $VERSION = '5.49_05';
 
 sub import {
     my ( $class, @arguments ) = @_;
@@ -82,43 +82,83 @@ Catalyst - The Elegant MVC Web Application Framework
 
     # use the helper to start a new application
     catalyst.pl MyApp
-    cd MyApp
 
     # add models, views, controllers
-    script/myapp_create.pl model Something
-    script/myapp_create.pl view Stuff
-    script/myapp_create.pl controller Yada
+    script/myapp_create.pl model Database DBIC dbi:SQLite:/path/to/db
+    script/myapp_create.pl view TT TT
+    script/myapp_create.pl controller Search
 
-    # built in testserver
+    # built in testserver -- use -r to restart automatically on changes
     script/myapp_server.pl
 
-    # command line interface
+    # command line testing interface
     script/myapp_test.pl /yada
 
+    ### in MyApp.pm
+    use Catalyst qw/-Debug/; # include plugins here as well
+    
+    sub foo : Global { # called for /foo, /foo/1, /foo/1/2, etc.
+        my ( $self, $c, @args ) = @_; # args are qw/on you/ for /foo/on/you
+        $c->stash->{template} = 'foo.tt';
+        # lookup something from db -- stash vars are passed to TT
+        $c->stash->{data} = MyApp::Model::Database::Foo->search;
+        if ( $c->req->params->{bar} ) { # access GET or POST parameters
+            $c->forward( 'bar' ); # process another action
+            # do something else after forward returns            
+        }
+    }
+    
+    # The foo.tt TT template can easily use the stash data from the database
+    [% WHILE (item = data.next) %]
+        [% item.foo %]
+    [% END %]
+    
+    # called for /bar/of/soap, /bar/of/soap/10, etc.
+    sub bar : Path('/bar/of/soap') { ... }
 
-    use Catalyst;
+    # called for / and only /, no other args
+    sub baz : Path  { ... } 
 
-    use Catalyst qw/My::Module My::OtherModule/;
-
-    use Catalyst '-Debug';
-
-    use Catalyst qw/-Debug -Engine=CGI/;
-
-    sub default : Private { $_[1]->res->output('Hello') } );
-
-    sub index : Path('/index.html') {
+    # called for all actions, from the top-most controller inwards
+    sub auto : Private { 
         my ( $self, $c ) = @_;
-        $c->res->output('Hello');
-        $c->forward('foo');
+        if ( !$c->user ) {
+            $c->res->redirect( '/login' ); # require login
+            return 0; # abort request and go immediately to end()
+        }
+        return 1;
+    }
+    
+    # called after the main action is finished
+    sub end : Private { 
+        my ( $self, $c ) = @_;
+        if ( scalar @{ $c->error } ) { ... } # handle errors
+        return if $c->res->body; # already have a response
+        $c->forward( 'MyApp::View::TT' ); # render template
     }
 
-    sub product : Regex('^product[_]*(\d*).html$') {
+    ### in MyApp/Controller/Foo.pm
+    # called for /foo/bar
+    sub bar : Local { ... }
+    
+    # overrides /foo, but not /foo/1, etc.
+    sub index : Path { ... }
+    
+    ### in MyApp/Controller/Foo/Bar.pm
+    # called for /foo/bar/baz
+    sub baz : Local { ... }
+    
+    # first MyApp auto is called, then Foo auto, then this
+    sub auto : Private { ... }
+    
+    # powerful regular expression paths are also possible
+    sub details : Regex('^product/(\w+)/details$') {
         my ( $self, $c ) = @_;
-        $c->stash->{template} = 'product.tt';
-        $c->stash->{product} = $c->req->snippets->[0];
+        # extract the (\w+) from the URI
+        my $product = $c->req->snippets->[0];
     }
 
-See also L<Catalyst::Manual::Intro>
+See L<Catalyst::Manual::Intro> for additional information.
 
 =head1 DESCRIPTION
 
@@ -127,10 +167,10 @@ The key concept of Catalyst is DRY (Don't Repeat Yourself).
 See L<Catalyst::Manual> for more documentation.
 
 Catalyst plugins can be loaded by naming them as arguments to the "use Catalyst" statement.
-Omit the C<Catalyst::Plugin::> prefix from the plugin name,
-so C<Catalyst::Plugin::My::Module> becomes C<My::Module>.
+Omit the C<Catalyst::Plugin::> prefix from the plugin name, i.e.,
+C<Catalyst::Plugin::My::Module> becomes C<My::Module>.
 
-    use Catalyst 'My::Module';
+    use Catalyst qw/My::Module/;
 
 Special flags like -Debug and -Engine can also be specified as arguments when
 Catalyst is loaded:
@@ -146,51 +186,163 @@ The following flags are supported:
 
 =item -Debug
 
-enables debug output, i.e.:
-
-    use Catalyst '-Debug';
-
-this is equivalent to:
-
-    use Catalyst;
-    sub debug { 1 }
-
-=item -Dispatcher
-
-Force Catalyst to use a specific dispatcher.
+Enables debug output.
 
 =item -Engine
 
-Force Catalyst to use a specific engine.
+Forces Catalyst to use a specific engine.
 Omit the C<Catalyst::Engine::> prefix of the engine name, i.e.:
 
-    use Catalyst '-Engine=CGI';
+    use Catalyst qw/-Engine=CGI/;
 
 =item -Home
 
-Force Catalyst to use a specific home directory.
+Forces Catalyst to use a specific home directory.
 
 =item -Log
 
-Specify log level.
+Specifies log level.
 
 =back
 
 =head1 METHODS
 
+=head2 Information about the current request
+
 =over 4
 
 =item $c->action
 
-Accessor for the current action
+Returns a L<Catalyst::Action> object for the current action, which stringifies to the action name.
+
+=item $c->namespace
+
+Returns the namespace of the current action, i.e., the uri prefix corresponding to the 
+controller of the current action.
+
+=item $c->request
+
+=item $c->req
+
+Returns the current L<Catalyst::Request> object.
+
+    my $req = $c->req;
+
+=back
+
+=head2 Processing and response to the current request
+
+=over 4
+
+=item $c->forward( $action [, \@arguments ] )
+
+=item $c->forward( $class, $method, [, \@arguments ] )
+
+Forwards processing to a private action. If you give a class name but 
+no method, process() is called. You may also optionally pass arguments 
+in an arrayref. The action will receive the arguments in @_ and $c->req->args. 
+Upon returning from the function, $c->req->args will be restored to the previous
+values.
+
+    $c->forward('/foo');
+    $c->forward('index');
+    $c->forward(qw/MyApp::Model::CDBI::Foo do_stuff/);
+    $c->forward('MyApp::View::TT');
+
+=cut
+
+sub forward { my $c = shift; $c->dispatcher->forward( $c, @_ ) }
+
+=item $c->detach( $action [, \@arguments ] )
+
+=item $c->detach( $class, $method, [, \@arguments ] )
+
+The same as C<forward>, but doesn't return.
+
+=cut
+
+sub detach { my $c = shift; $c->dispatcher->detach( $c, @_ ) }
+
+=item $c->error
+
+=item $c->error($error, ...)
+
+=item $c->error($arrayref)
+
+Returns an arrayref containing error messages.
+
+    my @error = @{ $c->error };
+
+Add a new error.
+
+    $c->error('Something bad happened');
+
+Clear errors.
+
+    $c->error(0);
+
+=cut
+
+sub error {
+    my $c = shift;
+    if ( $_[0] ) {
+        my $error = ref $_[0] eq 'ARRAY' ? $_[0] : [@_];
+        push @{ $c->{error} }, @$error;
+    }
+    elsif ( defined $_[0] ) { $c->{error} = undef }
+    return $c->{error} || [];
+}
+
+=item $c->response
+
+=item $c->res
+
+Returns the current L<Catalyst::Response> object.
+
+    my $res = $c->res;
+
+=item $c->stash
+
+Returns a hashref to the stash, which may be used to store data and pass it
+between components. You can also set hash keys by passing arguments.  The
+stash is automatically sent to the view.
+
+    $c->stash->{foo} = $bar;
+    $c->stash( { moose => 'majestic', qux => 0 } );
+    $c->stash( bar => 1, gorch => 2 ); # equivalent to passing a hashref
+    
+    # stash is automatically passed to the view for use in a template
+    $c->forward( 'MyApp::V::TT' );
+
+=cut
+
+sub stash {
+    my $c = shift;
+    if (@_) {
+        my $stash = @_ > 1 ? {@_} : $_[0];
+        while ( my ( $key, $val ) = each %$stash ) {
+            $c->{stash}->{$key} = $val;
+        }
+    }
+    return $c->{stash};
+}
+
+=item $c->state
+
+Contains the return value of the last executed action.
+
+=back
+
+=head2 Component Accessors
+
+=over 4
 
 =item $c->comp($name)
 
 =item $c->component($name)
 
-Get a component object by name.
-
-    $c->comp('MyApp::Model::MyModel')->do_stuff;
+Gets a component object by name.  This method is no longer recommended.
+$c->controller, $c->model, and $c->view should be used instead.
 
 =cut
 
@@ -205,7 +357,8 @@ sub component {
 
         my @names = (
             $name, "${appclass}::${name}",
-            map { "${appclass}::${_}::${name}" } qw/M V C/
+            map { "${appclass}::${_}::${name}" } 
+	    qw/Model M Controller C View V/
         );
 
         foreach my $try (@names) {
@@ -226,15 +379,9 @@ sub component {
     return sort keys %{ $c->components };
 }
 
-=item config
-
-Returns a hashref containing your applications settings.
-
-=cut
-
 =item $c->controller($name)
 
-Get a L<Catalyst::Controller> instance by name.
+Gets a L<Catalyst::Controller> instance by name.
 
     $c->controller('Foo')->do_stuff;
 
@@ -247,47 +394,9 @@ sub controller {
     return $c->comp("C::$name");
 }
 
-=item debug
-
-Overload to enable debug messages.
-
-=cut
-
-sub debug { 0 }
-
-=item $c->detach( $command [, \@arguments ] )
-
-Like C<forward> but doesn't return.
-
-=cut
-
-sub detach { my $c = shift; $c->dispatcher->detach( $c, @_ ) }
-
-=item $c->dispatcher
-
-Contains the dispatcher instance.
-Stringifies to class.
-
-=item $c->forward( $command [, \@arguments ] )
-
-Forward processing to a private action or a method from a class.
-If you define a class without method it will default to process().
-also takes an optional arrayref containing arguments to be passed
-to the new function. $c->req->args will be reset upon returning 
-from the function.
-
-    $c->forward('/foo');
-    $c->forward('index');
-    $c->forward(qw/MyApp::Model::CDBI::Foo do_stuff/);
-    $c->forward('MyApp::View::TT');
-
-=cut
-
-sub forward { my $c = shift; $c->dispatcher->forward( $c, @_ ) }
-
 =item $c->model($name)
 
-Get a L<Catalyst::Model> instance by name.
+Gets a L<Catalyst::Model> instance by name.
 
     $c->model('Foo')->do_stuff;
 
@@ -300,9 +409,67 @@ sub model {
     return $c->comp("M::$name");
 }
 
-=item $c->namespace
+=item $c->view($name)
 
-Accessor to the namespace of the current action
+Gets a L<Catalyst::View> instance by name.
+
+    $c->view('Foo')->do_stuff;
+
+=cut
+
+sub view {
+    my ( $c, $name ) = @_;
+    my $view = $c->comp("View::$name");
+    return $view if $view;
+    return $c->comp("V::$name");
+}
+
+=back
+
+=head2 Class data and helper classes
+
+=over 4
+
+=item $c->config
+
+Returns or takes a hashref containing the application's configuration.
+
+    __PACKAGE__->config({ db => 'dsn:SQLite:foo.db' });
+
+=item $c->debug
+
+Overload to enable debug messages (same as -Debug option).
+
+=cut
+
+sub debug { 0 }
+
+=item $c->dispatcher
+
+Returns the dispatcher instance. Stringifies to class name.
+
+=item $c->engine
+
+Returns the engine instance. Stringifies to the class name.
+
+=item $c->log
+
+Returns the logging object instance. Unless it is already set, Catalyst sets this up with a
+L<Catalyst::Log> object. To use your own log class:
+
+    $c->log( MyLogger->new );
+    $c->log->info( 'now logging with my own logger!' );
+
+Your log class should implement the methods described in the L<Catalyst::Log>
+man page.
+
+=cut
+
+=back
+
+=head2 Utility methods
+
+=over 4
 
 =item $c->path_to(@path)
 
@@ -321,11 +488,50 @@ sub path_to {
     else { return file( $c->config->{home}, @path ) }
 }
 
-=item $c->setup
+=item $c->plugin( $name, $class, @args )
 
-Setup.
+Helper method for plugins. It creates a classdata accessor/mutator and loads
+and instantiates the given class.
 
-    $c->setup;
+    MyApp->plugin( 'prototype', 'HTML::Prototype' );
+
+    $c->prototype->define_javascript_functions;
+
+=cut
+
+sub plugin {
+    my ( $class, $name, $plugin, @args ) = @_;
+    $plugin->require;
+
+    if ( my $error = $UNIVERSAL::require::ERROR ) {
+        Catalyst::Exception->throw(
+            message => qq/Couldn't load instant plugin "$plugin", "$error"/ );
+    }
+
+    eval { $plugin->import };
+    $class->mk_classdata($name);
+    my $obj;
+    eval { $obj = $plugin->new(@args) };
+
+    if ($@) {
+        Catalyst::Exception->throw( message =>
+              qq/Couldn't instantiate instant plugin "$plugin", "$@"/ );
+    }
+
+    $class->$name($obj);
+    $class->log->debug(qq/Initialized instant plugin "$plugin" as "$name"/)
+      if $class->debug;
+}
+
+=item MyApp->setup
+
+Initializes the dispatcher and engine, loads any plugins, and loads the
+model, view, and controller components.  You may also specify an array of
+plugins to load here, if you choose to not load them in the 'use Catalyst'
+line.
+
+    MyApp->setup;
+    MyApp->setup( qw/-Debug/ );
 
 =cut
 
@@ -375,11 +581,13 @@ sub setup {
         }
     }
 
-    $class->log->warn( "You are running an old helper script! "
-          . "Please update your scripts by regenerating the "
-          . "application and copying over the new scripts." )
-      if ( $ENV{CATALYST_SCRIPT_GEN}
-        && ( $ENV{CATALYST_SCRIPT_GEN} < $Catalyst::CATALYST_SCRIPT_GEN ) );
+    $class->log->warn(
+        <<"EOF") if ( $ENV{CATALYST_SCRIPT_GEN} && ( $ENV{CATALYST_SCRIPT_GEN} < $Catalyst::CATALYST_SCRIPT_GEN ) );
+You are running an old script!
+
+  Please update by running:
+    catalyst.pl -nonew -scripts $class
+EOF
 
     if ( $class->debug ) {
 
@@ -444,7 +652,7 @@ sub setup {
     $class->log->_flush() if $class->log->can('_flush');
 }
 
-=item $c->uri_for($path,[@args])
+=item $c->uri_for( $path, [ @args ] )
 
 Merges path with $c->request->base for absolute uri's and with
 $c->request->match for relative uri's, then returns a normalized
@@ -474,150 +682,6 @@ sub uri_for {
         $base )->canonical;
 }
 
-=item $c->error
-
-=item $c->error($error, ...)
-
-=item $c->error($arrayref)
-
-Returns an arrayref containing error messages.
-
-    my @error = @{ $c->error };
-
-Add a new error.
-
-    $c->error('Something bad happened');
-
-Clean errors.
-
-    $c->error(0);
-
-=cut
-
-sub error {
-    my $c = shift;
-    if ( $_[0] ) {
-        my $error = ref $_[0] eq 'ARRAY' ? $_[0] : [@_];
-        push @{ $c->{error} }, @$error;
-    }
-    elsif ( defined $_[0] ) { $c->{error} = undef }
-    return $c->{error} || [];
-}
-
-=item $c->engine
-
-Contains the engine instance.
-Stringifies to the class.
-
-=item $c->log
-
-Contains the logging object.  Unless it is already set Catalyst sets this up with a
-C<Catalyst::Log> object.  To use your own log class:
-
-    $c->log( MyLogger->new );
-    $c->log->info("now logging with my own logger!");
-
-Your log class should implement the methods described in the C<Catalyst::Log>
-man page.
-
-=item $c->plugin( $name, $class, @args )
-
-Instant plugins for Catalyst.
-Classdata accessor/mutator will be created, class loaded and instantiated.
-
-    MyApp->plugin( 'prototype', 'HTML::Prototype' );
-
-    $c->prototype->define_javascript_functions;
-
-=cut
-
-sub plugin {
-    my ( $class, $name, $plugin, @args ) = @_;
-    $plugin->require;
-
-    if ( my $error = $UNIVERSAL::require::ERROR ) {
-        Catalyst::Exception->throw(
-            message => qq/Couldn't load instant plugin "$plugin", "$error"/ );
-    }
-
-    eval { $plugin->import };
-    $class->mk_classdata($name);
-    my $obj;
-    eval { $obj = $plugin->new(@args) };
-
-    if ($@) {
-        Catalyst::Exception->throw( message =>
-              qq/Couldn't instantiate instant plugin "$plugin", "$@"/ );
-    }
-
-    $class->$name($obj);
-    $class->log->debug(qq/Initialized instant plugin "$plugin" as "$name"/)
-      if $class->debug;
-}
-
-=item $c->request
-
-=item $c->req
-
-Returns a C<Catalyst::Request> object.
-
-    my $req = $c->req;
-
-=item $c->response
-
-=item $c->res
-
-Returns a C<Catalyst::Response> object.
-
-    my $res = $c->res;
-
-=item $c->state
-
-Contains the return value of the last executed action.
-
-=item $c->stash
-
-Returns a hashref containing all your data.
-
-    print $c->stash->{foo};
-
-Keys may be set in the stash by assigning to the hash reference, or by passing
-either a single hash reference or a list of key/value pairs as arguments.
-
-For example:
-
-    $c->stash->{foo} ||= 'yada';
-    $c->stash( { moose => 'majestic', qux => 0 } );
-    $c->stash( bar => 1, gorch => 2 );
-
-=cut
-
-sub stash {
-    my $c = shift;
-    if (@_) {
-        my $stash = @_ > 1 ? {@_} : $_[0];
-        while ( my ( $key, $val ) = each %$stash ) {
-            $c->{stash}->{$key} = $val;
-        }
-    }
-    return $c->{stash};
-}
-
-=item $c->view($name)
-
-Get a L<Catalyst::View> instance by name.
-
-    $c->view('Foo')->do_stuff;
-
-=cut
-
-sub view {
-    my ( $c, $name ) = @_;
-    my $view = $c->comp("View::$name");
-    return $view if $view;
-    return $c->comp("V::$name");
-}
-
 =item $c->welcome_message
 
 Returns the Catalyst welcome HTML page.
@@ -769,7 +833,7 @@ EOF
 
 =over 4
 
-=item $c->benchmark($coderef)
+=item $c->benchmark( $coderef )
 
 Takes a coderef with arguments and returns elapsed time as float.
 
@@ -789,32 +853,32 @@ sub benchmark {
 
 =item $c->components
 
-Contains the components.
+Returns a hash of components.
 
-=item $c->context_class($class)
+=item $c->context_class
 
-Contains the context class.
+Returns or sets the context class.
 
 =item $c->counter
 
-Returns a hashref containing coderefs and execution counts.
-(Needed for deep recursion detection) 
+Returns a hashref containing coderefs and execution counts (needed for deep
+recursion detection).
 
 =item $c->depth
 
-Returns the actual forward depth.
+Returns the number of actions on the current internal execution stack.
 
 =item $c->dispatch
 
-Dispatch request to actions.
+Dispatches a request to actions.
 
 =cut
 
 sub dispatch { my $c = shift; $c->dispatcher->dispatch( $c, @_ ) }
 
-=item $c->dispatcher_class($class)
+=item $c->dispatcher_class
 
-Contains the dispatcher class.
+Returns or sets the dispatcher class.
 
 =item dump_these
 
@@ -828,14 +892,14 @@ sub dump_these {
     [ Request => $c->req ], [ Response => $c->res ], [ Stash => $c->stash ],;
 }
 
-=item $c->engine_class($class)
+=item $c->engine_class
 
-Contains the engine class.
+Returns or sets the engine class.
 
-=item $c->execute($class, $coderef)
+=item $c->execute( $class, $coderef )
 
-Execute a coderef in given class and catch exceptions.
-Errors are available via $c->error.
+Execute a coderef in given class and catch exceptions. Errors are available
+via $c->error.
 
 =cut
 
@@ -843,7 +907,11 @@ sub execute {
     my ( $c, $class, $code ) = @_;
     $class = $c->components->{$class} || $class;
     $c->state(0);
-    my $callsub = ( caller(1) )[3];
+
+    my $callsub =
+        ( caller(0) )[0]->isa('Catalyst::Action')
+      ? ( caller(2) )[3]
+      : ( caller(1) )[3];
 
     my $action = '';
     if ( $c->debug ) {
@@ -897,7 +965,7 @@ sub execute {
 
 =item $c->finalize
 
-Finalize request.
+Finalizes the request.
 
 =cut
 
@@ -929,7 +997,7 @@ sub finalize {
 
 =item $c->finalize_body
 
-Finalize body.
+Finalizes body.
 
 =cut
 
@@ -937,7 +1005,7 @@ sub finalize_body { my $c = shift; $c->engine->finalize_body( $c, @_ ) }
 
 =item $c->finalize_cookies
 
-Finalize cookies.
+Finalizes cookies.
 
 =cut
 
@@ -945,7 +1013,7 @@ sub finalize_cookies { my $c = shift; $c->engine->finalize_cookies( $c, @_ ) }
 
 =item $c->finalize_error
 
-Finalize error.
+Finalizes error.
 
 =cut
 
@@ -953,7 +1021,7 @@ sub finalize_error { my $c = shift; $c->engine->finalize_error( $c, @_ ) }
 
 =item $c->finalize_headers
 
-Finalize headers.
+Finalizes headers.
 
 =cut
 
@@ -994,7 +1062,7 @@ An alias for finalize_body.
 
 =item $c->finalize_read
 
-Finalize the input after reading is complete.
+Finalizes the input after reading is complete.
 
 =cut
 
@@ -1002,7 +1070,7 @@ sub finalize_read { my $c = shift; $c->engine->finalize_read( $c, @_ ) }
 
 =item $c->finalize_uploads
 
-Finalize uploads.  Cleans up any temporary files.
+Finalizes uploads.  Cleans up any temporary files.
 
 =cut
 
@@ -1010,7 +1078,7 @@ sub finalize_uploads { my $c = shift; $c->engine->finalize_uploads( $c, @_ ) }
 
 =item $c->get_action( $action, $namespace )
 
-Get an action in a given namespace.
+Gets an action in a given namespace.
 
 =cut
 
@@ -1018,7 +1086,7 @@ sub get_action { my $c = shift; $c->dispatcher->get_action(@_) }
 
 =item $c->get_actions( $action, $namespace )
 
-Get all actions of a given name in a namespace and all base namespaces.
+Gets all actions of a given name in a namespace and all parent namespaces.
 
 =cut
 
@@ -1026,7 +1094,7 @@ sub get_actions { my $c = shift; $c->dispatcher->get_actions( $c, @_ ) }
 
 =item handle_request( $class, @arguments )
 
-Handles the request.
+Called to handle each HTTP request.
 
 =cut
 
@@ -1071,10 +1139,10 @@ sub handle_request {
     return $status;
 }
 
-=item $c->prepare(@arguments)
+=item $c->prepare( @arguments )
 
-Turns the engine-specific request( Apache, CGI ... )
-into a Catalyst context .
+Creates a Catalyst context from an engine-specific request
+(Apache, CGI, etc.).
 
 =cut
 
@@ -1150,7 +1218,7 @@ sub prepare {
 
 =item $c->prepare_action
 
-Prepare action.
+Prepares action.
 
 =cut
 
@@ -1158,7 +1226,7 @@ sub prepare_action { my $c = shift; $c->dispatcher->prepare_action( $c, @_ ) }
 
 =item $c->prepare_body
 
-Prepare message body.
+Prepares message body.
 
 =cut
 
@@ -1187,7 +1255,7 @@ sub prepare_body {
 
 =item $c->prepare_body_chunk( $chunk )
 
-Prepare a chunk of data before sending it to HTTP::Body.
+Prepares a chunk of data before sending it to L<HTTP::Body>.
 
 =cut
 
@@ -1198,7 +1266,7 @@ sub prepare_body_chunk {
 
 =item $c->prepare_body_parameters
 
-Prepare body parameters.
+Prepares body parameters.
 
 =cut
 
@@ -1209,7 +1277,7 @@ sub prepare_body_parameters {
 
 =item $c->prepare_connection
 
-Prepare connection.
+Prepares connection.
 
 =cut
 
@@ -1220,7 +1288,7 @@ sub prepare_connection {
 
 =item $c->prepare_cookies
 
-Prepare cookies.
+Prepares cookies.
 
 =cut
 
@@ -1228,7 +1296,7 @@ sub prepare_cookies { my $c = shift; $c->engine->prepare_cookies( $c, @_ ) }
 
 =item $c->prepare_headers
 
-Prepare headers.
+Prepares headers.
 
 =cut
 
@@ -1236,7 +1304,7 @@ sub prepare_headers { my $c = shift; $c->engine->prepare_headers( $c, @_ ) }
 
 =item $c->prepare_parameters
 
-Prepare parameters.
+Prepares parameters.
 
 =cut
 
@@ -1248,7 +1316,7 @@ sub prepare_parameters {
 
 =item $c->prepare_path
 
-Prepare path and base.
+Prepares path and base.
 
 =cut
 
@@ -1256,7 +1324,7 @@ sub prepare_path { my $c = shift; $c->engine->prepare_path( $c, @_ ) }
 
 =item $c->prepare_query_parameters
 
-Prepare query parameters.
+Prepares query parameters.
 
 =cut
 
@@ -1279,7 +1347,7 @@ sub prepare_query_parameters {
 
 =item $c->prepare_read
 
-Prepare the input for reading.
+Prepares the input for reading.
 
 =cut
 
@@ -1287,7 +1355,7 @@ sub prepare_read { my $c = shift; $c->engine->prepare_read( $c, @_ ) }
 
 =item $c->prepare_request
 
-Prepare the engine request.
+Prepares the engine request.
 
 =cut
 
@@ -1295,7 +1363,7 @@ sub prepare_request { my $c = shift; $c->engine->prepare_request( $c, @_ ) }
 
 =item $c->prepare_uploads
 
-Prepare uploads.
+Prepares uploads.
 
 =cut
 
@@ -1323,23 +1391,23 @@ sub prepare_uploads {
 
 =item $c->prepare_write
 
-Prepare the output for writing.
+Prepares the output for writing.
 
 =cut
 
 sub prepare_write { my $c = shift; $c->engine->prepare_write( $c, @_ ) }
 
-=item $c->request_class($class)
+=item $c->request_class
 
-Contains the request class.
+Returns or sets the request class.
 
-=item $c->response_class($class)
+=item $c->response_class
 
-Contains the response class.
+Returns or sets the response class.
 
 =item $c->read( [$maxlength] )
 
-Read a chunk of data from the request body.  This method is designed to be
+Reads a chunk of data from the request body.  This method is designed to be
 used in a while loop, reading $maxlength bytes on every call.  $maxlength
 defaults to the size of the request if not specified.
 
@@ -1359,7 +1427,7 @@ sub run { my $c = shift; return $c->engine->run( $c, @_ ) }
 
 =item $c->set_action( $action, $code, $namespace, $attrs )
 
-Set an action in a given namespace.
+Sets an action in a given namespace.
 
 =cut
 
@@ -1367,7 +1435,7 @@ sub set_action { my $c = shift; $c->dispatcher->set_action( $c, @_ ) }
 
 =item $c->setup_actions($component)
 
-Setup actions for a component.
+Sets up actions for a component.
 
 =cut
 
@@ -1375,7 +1443,7 @@ sub setup_actions { my $c = shift; $c->dispatcher->setup_actions( $c, @_ ) }
 
 =item $c->setup_components
 
-Setup components.
+Sets up components.
 
 =cut
 
@@ -1389,7 +1457,7 @@ sub setup_components {
             return $component;
         }
 
-        my $suffix = Catalyst::Utils::class2classsuffix($class);
+        my $suffix = Catalyst::Utils::class2classsuffix($component);
         my $config = $class->config->{$suffix} || {};
 
         my $instance;
@@ -1671,7 +1739,7 @@ sub setup_plugins {
 
 =item $c->stack
 
-Contains the stack.
+Returns the stack.
 
 =item $c->write( $data )
 
@@ -1692,7 +1760,7 @@ sub write {
 
 =item version
 
-Returns the Catalyst version number. mostly useful for powered by messages
+Returns the Catalyst version number. Mostly useful for "powered by" messages
 in template systems.
 
 =cut
@@ -1786,12 +1854,18 @@ Web:
 
     http://catalyst.perl.org
 
+Wiki:
+
+    http://dev.catalyst.perl.org
+
 =head1 SEE ALSO
 
 =over 4
 
 =item L<Catalyst::Manual> - The Catalyst Manual
 
+=item L<Catalyst::Component>, L<Catalyst::Base> - Base classes for components
+
 =item L<Catalyst::Engine> - Core Engine
 
 =item L<Catalyst::Log> - The Log Class.
@@ -1832,6 +1906,8 @@ Dan Sully
 
 Danijel Milicevic
 
+David Kamholz
+
 David Naughton
 
 Gary Ashton Jones
